@@ -10,7 +10,7 @@ import match_cost.matching as matching
 import match_cost.tmp_image_utils as tmp_image_utils
 import time
 import shutil
-import pytesseract
+import match_cost.pytesseract as pytesseract
 import match_cost.match_conf as match_conf
 from util.logger import logger
 
@@ -31,6 +31,7 @@ class image_matcher:
         self.tab_contents = match_conf.get_feed_tab_text(self.pkg_name)
         self.ad_text = match_conf.get_ad_text(self.pkg_name)
         self.is_ad_video = False
+        environ = os.environ.copy()
 
     def set_vedio_load_tmp_dir(self, vedio_load_tmp_dir):
         self.vedio_load_tmp_dir = vedio_load_tmp_dir
