@@ -29,6 +29,10 @@ def get_config_value(*args) -> str:
 
 pkg_name = get_config_value('pkg_name')
 
+type = get_config_value('test_type')
+
+test_platform = get_config_value('test_platform')
+
 
 def get_match_config_value(*args) -> str:
     """
